[hide private]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- metapho.metapho.Image: An image, with additional info such as rotation and tags.
- object: The most base type
  - gobject.GInterface: Interface GInterface
    - gtk.Buildable
      - gtk.Widget: Object GtkWidget
        - gtk.Container: Object GtkContainer
          - gtk.Table: Object GtkTable
            - metapho.gtkpho.TagViewer: A PyGTK widget for showing tags.
        - gtk.DrawingArea: Object GtkDrawingArea
          - metapho.gtkpho.ImageViewer: A PyGTK image viewer widget for metapho.
    - atk.ImplementorIface
      - gtk.Widget: Object GtkWidget
        - gtk.Container: Object GtkContainer
          - gtk.Table: Object GtkTable
            - metapho.gtkpho.TagViewer: A PyGTK widget for showing tags.
        - gtk.DrawingArea: Object GtkDrawingArea
          - metapho.gtkpho.ImageViewer: A PyGTK image viewer widget for metapho.
  - unreachable.GObject: Object GObject
    - gtk.Object: Object GtkObject
      - gtk.Widget: Object GtkWidget
        - gtk.Container: Object GtkContainer
          - gtk.Table: Object GtkTable
            - metapho.gtkpho.TagViewer: A PyGTK widget for showing tags.
        - gtk.DrawingArea: Object GtkDrawingArea
          - metapho.gtkpho.ImageViewer: A PyGTK image viewer widget for metapho.
  - metapho.main.MetaPhoWindow: The main controller window for metapho.
  - metapho.metapho.Tagger: Manages tags for images.
    - metapho.gtkpho.TagViewer: A PyGTK widget for showing tags.